My Project: src/c/so3_about.c Source File

My Project

so3_about.c
Go to the documentation of this file.
1 // S03 package to perform Wigner transform on the rotation group SO(3)
2 // Copyright (C) 2013 Martin Büttner and Jason McEwen
3 // See LICENSE.txt for license details
4
16 #include <stdio.h>
17
18 int main(int argc, char *argv[]) {
19
20 printf("%s\n", "===================================================================");
21 printf("%s\n", "SO3 package to perform Wigner transform on the rotation group SO(3)");
22 printf("%s\n", "By Martin Büttner and Jason McEwen");
23
24 printf("%s\n", "See www.jasonmcewen.org for more information.");
25 printf("%s\n", "See LICENSE.txt for license details.");
26
27 printf("%s%s\n", "Version: ", SO3_VERSION);
28 printf("%s%s\n", "Build: ", SO3_BUILD);
29 printf("%s\n", "===================================================================");
30
31 return 0;
32
33 }
34
main
int main(int argc, char *argv[])
Definition: so3_about.c:18